django-linkthru
==================

:author: Colin Powell
:date: 2011-04-26
:by: One Cardinal Web Development
:license: GPLv3

Big chunks of thie projects were taken from @andrewebdev's excellent adzone project. What was need though, was much less of a full-featured ad management app, but just a way to provide on-site link throughs to miscellaneous content.

In other words, I wanted on-site ads that wouldn't get caught by the adblockers and didn't keep track of advertisers or categories or other junk like that. Just some text or an image, linked to a specific url.


